# Changelog

`yayaml` aims to adhere to [semantic versioning](https://semver.org/).

## 0.1.0

This initial version moves the YAML-related tools that were integrated into the [paramspace](https://gitlab.com/blsqr/paramspace) package (prior to its 2.6 release) into this new package named `yayaml`.

yay :)

Specifically, it is based on code from commit [`7b1d2e7`](https://gitlab.com/blsqr/paramspace/-/commit/7b1d2e7e44fe38dadb0e6af901d72299b1ed6dd0), but already makes a number of abstractions and improvements.
